API Reference
=============

Submodules
----------

ewdm.helpers module
-------------------

.. automodule:: ewdm.helpers
   :members:
   :undoc-members:
   :show-inheritance:

ewdm.main module
----------------

.. automodule:: ewdm.main
   :members:
   :undoc-members:
   :show-inheritance:

ewdm.parameters module
----------------------

.. automodule:: ewdm.parameters
   :members:
   :undoc-members:
   :show-inheritance:

ewdm.plots module
-----------------

.. automodule:: ewdm.plots
   :members:
   :undoc-members:
   :show-inheritance:

ewdm.sources module
-------------------

.. automodule:: ewdm.sources
   :members:
   :undoc-members:
   :show-inheritance:

ewdm.wavelets module
--------------------

.. automodule:: ewdm.wavelets
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ewdm
   :members:
   :undoc-members:
   :show-inheritance:
